@@ -39,6 +39,8 @@ class _PackagerFiles:
         self.files = [getattr(self, key) for key in dir(self) if key.startswith("file_")]
         self.files_by_relative_path = {file.relative_path: file for file in self.files}
 
+        self.file_personal_readme = GenerateFile(self.localrepo.get_readme_path(), self.generate_personal_readme, self, aesthetic=True)
+
     def relative_path_is_aesthetic(self, relative_path):
         """ Relative to package path. None if not defined as a GenerateFile instance.
 
@@ -175,12 +177,12 @@ class _PackagerFiles:
 
             :param generalpackager.Packager self: """
         # Description
-        markdown = Markdown(self.localrepo.description, header=f"{self.name} {self.localrepo.version}")
+        markdown = self.get_description_markdown()
 
-        # Badges
-        markdown.add_lines(*self.get_badges_dict().values())
+        # Information
+        self.get_information_markdown().set_parent(parent=markdown)
 
-        # Table of contents - Placeholder
+        # Table of contents
         contents = Markdown(header="Contents", parent=markdown)
 
         # Installation
@@ -192,7 +194,7 @@ class _PackagerFiles:
         # Todos
         todos = self.localrepo.get_todos()
         if todos:
-            Markdown(header="Todo", parent=markdown).add_table_lines(*todos)
+            Markdown(header=f"Todo ({len(todos)}x)", parent=markdown).add_table_lines(*todos)
 
         # Table of contents - Configuration
         self.configure_contents_markdown(markdown=contents)
@@ -201,4 +203,50 @@ class _PackagerFiles:
         self.get_footnote_markdown().set_parent(parent=markdown)
 
         return markdown
+
+    def generate_personal_readme(self):
+        """ Generate personal readme markdown and overwrite README.md in local repo.
+
+            :param generalpackager.Packager self: """
+        # Description
+        markdown = Markdown(header="General").add_list_lines(
+            "A collection of connected packages.",
+            "Violently updated with little regard for backwards compatability.",
+            "Automatic workflows to unittest, sync and publish.",
+        )
+
+        # Package information
+        self.get_information_markdown(*self.load_general_packagers().values()).set_parent(parent=markdown)
+
+        # Footnote
+        self.get_footnote_markdown(commit=False).set_parent(parent=markdown)
+
+        return markdown
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
 
