@@ -9,7 +9,6 @@ class _PackagerMarkdown:
         """ Get badges as a dict.
 
             :param generalpackager.Packager self: """
-
         return {
             "UnitTests": f"[![workflow Actions Status](https://github.com/ManderaGeneral/{self.name}/workflows/workflow/badge.svg)](https://github.com/ManderaGeneral/{self.name}/actions)",
             "Commit": f"![GitHub last commit](https://img.shields.io/github/last-commit/ManderaGeneral/{self.name})",
@@ -18,6 +17,37 @@ class _PackagerMarkdown:
             "Operating System": f"[![Generic badge](https://img.shields.io/badge/platforms-{'%20%7C%20'.join(self.os)}-blue.svg)](https://shields.io/)",
         }
 
+    def get_description_markdown(self):
+        """ Get information table.
+
+            :param generalpackager.Packager self: """
+        part_of = f"This package and {len(self.packagers_dict) - 1} other make up {Markdown.link(text='ManderaGeneral', url='https://github.com/Mandera')}."
+        header = f"{self.name} {self.localrepo.version}"
+        return Markdown(self.localrepo.description, "\n", part_of, header=header)
+
+    def get_information_markdown(self, *packagers):
+        """ Get information table.
+
+            :param generalpackager.Packager self: """
+        if not packagers:
+            packagers = (self, )
+
+        markdown = Markdown(header="Information")
+
+        python_url = "https://www.python.org/downloads/release/python-"
+
+        list_of_dicts = []
+        for packager in packagers:
+            list_of_dicts.append({
+                "Package": Markdown.link(text=packager.name, url=packager.github.url),
+                "Version": Markdown.link(text=packager.localrepo.version, url=packager.pypi.url),
+                "Latest Release": packager.pypi.get_datetime(),
+                "Python": ", ".join([Markdown.link(text=ver, url=f"{python_url}{str(ver).replace('.', '')}0/") for ver in packager.python]),
+                "Platform": ", ".join(map(str.capitalize, packager.os)),
+            })
+        markdown.add_table_lines(*list_of_dicts, sort_by="Package")
+        return markdown
+
     def get_installation_markdown(self):
         """ Get install markdown.
 
@@ -79,10 +109,14 @@ class _PackagerMarkdown:
         view_str = self.localmodule.objInfo.view(custom_repr=self._attr_repr, print_out=False)
         return Markdown(header="Attributes").add_pre_lines(view_str)
 
-    def get_footnote_markdown(self):
+    def get_footnote_markdown(self, commit=True):
         """ Get a markdown for footnote containing date, time and commit link.
 
-            :param generalpackager.Packager self: """
-        line = f"Generated {current_datetime_formatted()} for commit {self.github_link(text=self.commit_sha, suffix=f'commit/{self.commit_sha}')}."
+            :param generalpackager.Packager self:
+            :param commit: """
+        line = f"Generated {current_datetime_formatted()}"
+        if commit:
+            line += f" for commit {self.github_link(text=self.commit_sha, suffix=f'commit/{self.commit_sha}')}."
+
         return Markdown(line).wrap_with_tags("sup")
 
